Temp

Struct Temp 

pub struct Temp { /* private fields */ }
An instance of a Temporary Object. The Object will be deleted when the Object is dropped.

Additional Temporary Objects can be associated to an instance, such that they will be tied to the main Object’s lifetime and dropped together.

There is no distinction between Files/Directories/other objects in a Temp. The distinction is only made within the Builder, and it is up to the program to know what kind of object is stored.

Implementations

Source

impl Temp

pub fn associate(&mut self, temp: Temp)

Associate another Temporary Object to the caller. It will be tied to the caller’s lifetime, and dropped with it.

pub fn name(&self) -> &str

Get the name of the temporary object.

pub fn path(&self) -> &Path

Get the path the Temporary Object is located within.

pub fn full(&self) -> PathBuf

The full path to the object, including its name.

Make a Symlink from the Temporary Object. This link will be associated with the caller, such that the Link will be deleted with the Object.