pub struct Temp { /* private fields */ }Expand description
An instance of a Temporary Object. The Object will be deleted when the Object is dropped.
Additional Temporary Objects can be associated to an instance, such that they will be tied to the main Object’s lifetime and dropped together.
There is no distinction between Files/Directories/other objects in a Temp. The distinction is only made within the Builder, and it is up to the program to know what kind of object is stored.
Implementations